from turtle import *

up()

def stRound():
    goto(517, -43)
    write("א", font=("Arial", 25, "normal"))

    goto(467, -43)
    write("ב", font=("Arial", 25, "normal"))

    goto(417, -43)
    write("ג", font=("Arial", 25, "normal"))

    goto(367, -43)
    write("ד", font=("Arial", 25, "normal"))

    goto(317, -43)
    write("ה", font=("Arial", 25, "normal"))

    goto(267, -43)
    write("ו", font=("Arial", 25, "normal"))

    goto(217, -43)
    write("ז", font=("Arial", 25, "normal"))

    goto(167, -43)
    write("ח", font=("Arial", 25, "normal"))

    goto(117, -43)
    write("ט", font=("Arial", 25, "normal"))

def ndRound():
    goto(523, -93)
    write("י", font=("Arial", 25, "normal"))

    goto(467, -93)
    write("כ", font=("Arial", 25, "normal"))

    goto(417, -93)
    write("ל", font=("Arial", 25, "normal"))

    goto(367, -93)
    write("מ", font=("Arial", 25, "normal"))

    goto(317, -93)
    write("נ", font=("Arial", 25, "normal"))

    goto(267, -93)
    write("ס", font=("Arial", 25, "normal"))

    goto(217, -93)
    write("ע", font=("Arial", 25, "normal"))

    goto(167, -93)
    write("פ", font=("Arial", 25, "normal"))

    goto(117, -93)
    write("צ", font=("Arial", 25, "normal"))

def rdRound():
    goto(517, -143)
    write("ק", font=("Arial", 25, "normal"))

    goto(467, -143)
    write("ר", font=("Arial", 25, "normal"))

    goto(417, -143)
    write("ש", font=("Arial", 25, "normal"))

    goto(367, -143)
    write("ת", font=("Arial", 25, "normal"))

    goto(317, -143)
    write("ך", font=("Arial", 25, "normal"))

    goto(267, -143)
    write("ם", font=("Arial", 25, "normal"))

    goto(217, -143)
    write("ן", font=("Arial", 25, "normal"))

    goto(167, -143)
    write("ף", font=("Arial", 25, "normal"))

    goto(117, -143)
    write("ץ", font=("Arial", 25, "normal"))

stRound()
ndRound()
rdRound()